@@ -109,11 +109,7 @@ void Transfer::init()//TODO think about e, maybe not have it at all in the const
 #ifdef HAVE_NEPOMUK
 void Transfer::setNepomukHandler(NepomukHandler *handler)
 {
-    if (m_nepomukHandler)
-    {
-        delete(m_nepomukHandler);
-        m_nepomukHandler = 0;
-    }
+    delete(m_nepomukHandler);
     m_nepomukHandler = handler;
 }
 #endif //HAVE_NEPOMUK
@@ -217,7 +213,7 @@ void Transfer::checkShareRatio()
         setDownloadLimit(0, Transfer::InvisibleSpeedLimit);
 }
 
-void Transfer::setLog(const QString& message, LogLevel level)
+void Transfer::setLog(const QString& message, Transfer::LogLevel level)
 {
     QString msg("<font color=\"blue\">" + QTime::currentTime().toString() + "</font> : ");
     if (level == Log_Error)
@@ -312,17 +308,14 @@ void Transfer::setStatus(Job::Status jobStatus, const QString &text, const QPixm
 {
     const bool statusChanged = (status() != jobStatus);
     QString statusText = text;
-    if (statusText.isEmpty())
-    {
+    if (statusText.isEmpty()) {
         statusText = i18nc(STATUSTEXTS[jobStatus].context, STATUSTEXTS[jobStatus].name);
     }
 
     //always prefer pix, if it is set
-    if (pix.isNull()) {
+    if (!pix.isNull()) {
         m_statusPixmap = pix;
-    }
-
-    if (statusChanged || m_statusPixmap.isNull()) {
+    } else if (statusChanged || m_statusPixmap.isNull()) {
         m_statusPixmap = SmallIcon(STATUSICONS[jobStatus]);
     }
 
