@@ -90,9 +90,13 @@ void BTTransfer::deinit()
     }
     tmpDir.cdUp();
     tmpDir.rmdir(m_source.fileName().remove(".torrent"));
-    kDebug(5001) << m_source.url();
-    QFile torrentFile(m_source.toLocalFile());
-    torrentFile.remove();
+
+    //only remove the .torrent file if it was downloaded by KGet
+    if (!m_tmpTorrentFile.isEmpty()) {
+        kDebug(5001) << "Removing" << m_tmpTorrentFile;
+        QFile torrentFile(m_tmpTorrentFile);
+        torrentFile.remove();
+    }
 }
 
 void BTTransfer::synchronDeinit()
@@ -127,7 +131,8 @@ void BTTransfer::start()
         if (!m_source.isLocalFile())
         {
             kDebug(5001) << m_dest.path();
-            Download *download = new Download(m_source, QString(KStandardDirs::locateLocal("appdata", "tmp/") + m_source.fileName()));
+            m_tmpTorrentFile = QString(KStandardDirs::locateLocal("appdata", "tmp/") + m_dest.fileName());
+            Download *download = new Download(m_source, m_tmpTorrentFile);
 
             setStatus(Job::Stopped, i18n("Downloading Torrent File...."), SmallIcon("document-save"));
             setTransferChange(Tc_Status, true);
