@@ -21,6 +21,7 @@
 #include "core/filemodel.h"
 #include "core/urlchecker.h"
 #include "core/verifier.h"
+#include "core/signature.h"
 #ifdef HAVE_NEPOMUK
 #include "core/nepomukhandler.h"
 #include <Nepomuk/Variant>
@@ -81,7 +82,7 @@ void Metalink::downloadMetalink()
 
     setStatus(Job::Stopped, i18n("Downloading Metalink File...."), SmallIcon("document-save"));
     setTransferChange(Tc_Status, true);
-    Download *download = new Download(m_source, KStandardDirs::locateLocal("appdata", "metalinks/") + m_source.fileName());
+    Download *download = new Download(m_source, QString(KStandardDirs::locateLocal("appdata", "metalinks/") + m_source.fileName()));
     connect(download, SIGNAL(finishedSuccessfully(KUrl, QByteArray)), SLOT(metalinkInit(KUrl, QByteArray)));
 }
 
@@ -154,6 +155,7 @@ bool Metalink::metalinkInit(const KUrl &src, const QByteArray &data)
         connect(dataFactory, SIGNAL(dataSourceFactoryChange(Transfer::ChangesFlags)), this, SLOT(slotDataSourceFactoryChange(Transfer::ChangesFlags)));
         connect(dataFactory->verifier(), SIGNAL(verified(bool)), this, SLOT(slotVerified(bool)));
         connect(dataFactory->signature(), SIGNAL(verified(int)), this, SLOT(slotSignatureVerified()));
+        connect(dataFactory, SIGNAL(log(QString,Transfer::LogLevel)), this, SLOT(setLog(QString,Transfer::LogLevel)));
 
         //add the DataSources
         for (int i = 0; i < urlList.size(); ++i)
@@ -171,7 +173,7 @@ bool Metalink::metalinkInit(const KUrl &src, const QByteArray &data)
         }
         else
         {
-            dataFactory->verifier()->model()->addChecksums((*it).verification.hashes);
+            dataFactory->verifier()->addChecksums((*it).verification.hashes);
             foreach (const KGetMetalink::Pieces &pieces, (*it).verification.pieces) {
                 dataFactory->verifier()->addPartialChecksums(pieces.type, pieces.length, pieces.hashes);
             }
@@ -181,7 +183,7 @@ bool Metalink::metalinkInit(const KUrl &src, const QByteArray &data)
             QHash<QString, QString>::const_iterator itEnd = signatures.constEnd();
             for (it = signatures.constBegin(); it != itEnd; ++it) {
                 if (it.key().toLower() == "pgp") {
-                    dataFactory->signature()->setSignature(*it);
+                    dataFactory->signature()->setAsciiDetatchedSignature(*it);
                 }
             }
 
@@ -619,6 +621,7 @@ void Metalink::load(const QDomElement *element)
         m_dataSourceFactory[file->dest()] = file;
         connect(file->verifier(), SIGNAL(verified(bool)), this, SLOT(slotVerified(bool)));
         connect(file->signature(), SIGNAL(verified(int)), this, SLOT(slotSignatureVerified()));
+        connect(file, SIGNAL(log(QString,Transfer::LogLevel)), this, SLOT(setLog(QString,Transfer::LogLevel)));
 
         //start the DataSourceFactories that were Started when KGet was closed
         if (file->status() == Job::Running) {
