@@ -17,6 +17,7 @@
 // #include "mirrors.h"
 #include "core/filemodel.h"
 #include "core/verifier.h"
+#include "core/signature.h"
 
 #include <kiconloader.h>
 #include <KIO/CopyJob>
@@ -50,6 +51,7 @@ void TransferMultiSegKio::init()
         connect(m_dataSourceFactory, SIGNAL(capabilitiesChanged()), this, SLOT(slotUpdateCapabilities()));
         connect(m_dataSourceFactory, SIGNAL(dataSourceFactoryChange(Transfer::ChangesFlags)), this, SLOT(slotDataSourceFactoryChange(Transfer::ChangesFlags)));
         connect(m_dataSourceFactory->verifier(), SIGNAL(verified(bool)), this, SLOT(slotVerified(bool)));
+        connect(m_dataSourceFactory, SIGNAL(log(QString,Transfer::LogLevel)), this, SLOT(setLog(QString,Transfer::LogLevel)));
 
         m_dataSourceFactory->addMirror(m_source, MultiSegKioSettings::segments());
 
@@ -248,7 +250,7 @@ void TransferMultiSegKio::slotSearchUrls(const QList<KUrl> &urls)
 
 void TransferMultiSegKio::slotChecksumFound(QString type, QString checksum)
 {
-    m_dataSourceFactory->verifier()->model()->addChecksum(type, checksum);
+    m_dataSourceFactory->verifier()->addChecksum(type, checksum);
 }
 
 QHash<KUrl, QPair<bool, int> > TransferMultiSegKio::availableMirrors(const KUrl &file) const
@@ -293,6 +295,8 @@ FileModel *TransferMultiSegKio::fileModel()
         m_fileModel->setData(sizeIndex, static_cast<qlonglong>(m_dataSourceFactory->size()));
         QModelIndex checksumVerified = m_fileModel->index(m_dest, FileItem::ChecksumVerified);
         m_fileModel->setData(checksumVerified, verifier()->status());
+        QModelIndex signatureVerified = m_fileModel->index(m_dest, FileItem::SignatureVerified);
+        m_fileModel->setData(signatureVerified, signature()->status());
     }
 
     return m_fileModel;
