@@ -52,6 +52,7 @@ TransfersView::TransfersView(QWidget * parent)
     connect(header(), SIGNAL(customContextMenuRequested(const QPoint &)),
                       SLOT(slotShowHeaderMenu(const QPoint &)));
     connect(header(), SIGNAL(sectionMoved(int,int,int)), this, SLOT(slotSectionMoved(int,int,int)));
+    connect(header(), SIGNAL(sectionResized(int,int,int)), this, SLOT(slotSaveHeader()));
     connect(this,     SIGNAL(doubleClicked(const QModelIndex &)),
             this,     SLOT(slotItemActivated(const QModelIndex &)));
     connect(this,     SIGNAL(collapsed(const QModelIndex &)),
@@ -62,14 +63,11 @@ TransfersView::TransfersView(QWidget * parent)
 
 TransfersView::~TransfersView()
 {
-    Settings::setHeaderState(header()->saveState().toBase64());
-    Settings::self()->writeConfig();
 }
 
 void TransfersView::setModel(QAbstractItemModel * model)
 {
     QTreeView::setModel(model);
-
     int nGroups = model->rowCount(QModelIndex());
 
     for(int i = 0; i < nGroups; i++)
@@ -79,12 +77,15 @@ void TransfersView::setModel(QAbstractItemModel * model)
     }
 
     QByteArray loadedState = QByteArray::fromBase64(Settings::headerState().toAscii());
-    if (loadedState.isNull()) {
-        setColumnWidth(0 , 250);
+    if (loadedState.isEmpty()) {
+        setColumnWidth(0 , 230);
     } else {
         header()->restoreState(loadedState);
     }
 
+    //Workaround if the saved headerState is corrupted
+    header()->setRootIndex(QModelIndex());
+
     populateHeaderActions();
     toggleMainGroup();
     connect(model, SIGNAL(rowsRemoved(const QModelIndex&, int, int)), SLOT (toggleMainGroup()));
@@ -150,6 +151,7 @@ void TransfersView::slotHideSection(int logicalIndex)
 {
     const bool hide = !header()->isSectionHidden(logicalIndex);
     header()->setSectionHidden(logicalIndex, hide);
+    slotSaveHeader();
 }
 
 void TransfersView::slotSectionMoved(int logicalIndex, int oldVisualIndex, int newVisualIndex)
@@ -173,6 +175,13 @@ void TransfersView::slotSectionMoved(int logicalIndex, int oldVisualIndex, int n
     QAction *action = actions[oldVisualIndex];
     m_headerMenu->removeAction(action);
     m_headerMenu->insertAction(before, action);
+    slotSaveHeader();
+}
+
+void TransfersView::slotSaveHeader()
+{
+    Settings::setHeaderState(header()->saveState().toBase64());
+    Settings::self()->writeConfig();
 }
 
 void TransfersView::dragMoveEvent ( QDragMoveEvent * event )
