@@ -189,12 +189,12 @@ QWidget *ChatView::mainWidget()
 	return this;
 }
 
-bool ChatView::canSend()
+bool ChatView::canSend() const
 {
 	return editPart()->canSend();
 }
 
-bool ChatView::canSendFile()
+bool ChatView::canSendFile() const
 {
 	Kopete::ContactPtrList contacts = msgManager()->members();
 	if ( contacts.count() != 1 )
@@ -266,7 +266,7 @@ void ChatView::resetFontAndColor()
 	if ( !mc )
 		return;
 
-	QString contactListGroup = QLatin1String("chatwindow_") + mc->metaContactId();
+	QString contactListGroup = QString(QLatin1String("chatwindow_") + QString(mc->metaContactId()));
 	KConfigGroup config = KGlobal::config()->group(contactListGroup);
 	editPart()->resetConfig( config );
 	config.sync();
@@ -332,7 +332,7 @@ bool ChatView::isVisible()
 	return ( m_mainWindow && m_mainWindow->isVisible() );
 }
 
-bool ChatView::sendInProgress()
+bool ChatView::sendInProgress() const
 {
 	return d->sendInProgress;
 }
@@ -543,7 +543,7 @@ void ChatView::slotContactAdded(const Kopete::Contact *contact, bool suppress)
 		this, SLOT( slotPropertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ) ) ;
 	}
 
-	if( !suppress && m_manager->members().count() > 1 ) {
+	if( !suppress && Kopete::BehaviorSettings::self()->showEvents() && m_manager->members().count() > 1 ) {
 		QString contactName = m_messagePart->formatName(contact, Qt::PlainText);
 		sendInternalMessage(  i18n("%1 has joined the chat.", contactName) );
 	}
@@ -588,7 +588,7 @@ void ChatView::slotContactRemoved( const Kopete::Contact *contact, const QString
 			}
 		}
 
-		if ( !suppressNotification )
+		if ( !suppressNotification && Kopete::BehaviorSettings::self()->showEvents() )
 		{
 			QString contactName = m_messagePart->formatName(contact, Qt::PlainText);
 			if ( reason.isEmpty() )
@@ -770,8 +770,8 @@ void ChatView::saveChatSettings()
 	if ( !mc )
 		return;
 
-	QString contactListGroup = QLatin1String("chatwindow_") +
-	                           mc->metaContactId();
+	QString contactListGroup = QString(QLatin1String("chatwindow_") +
+	                           QString(mc->metaContactId()));
     KConfigGroup config = KGlobal::config()->group(contactListGroup);
 
 	// If settings are the same as default delete entry from config. This will propagate global setting change.
@@ -796,8 +796,8 @@ void ChatView::loadChatSettings()
 		return; //can't load with more than one other person in the chat
 
 	//read settings for metacontact
-	QString contactListGroup = QLatin1String("chatwindow_") +
-	                           contacts.first()->metaContact()->metaContactId();
+	QString contactListGroup = QString(QLatin1String("chatwindow_") +
+	                           QString(contacts.first()->metaContact()->metaContactId()));
 	KConfigGroup config(KGlobal::config(), contactListGroup );
 	bool enableRichText = config.readEntry( "EnableRichText", Kopete::BehaviorSettings::self()->richTextByDefault() );
 	editPart()->textEdit()->setRichTextEnabled( enableRichText );
