@@ -20,6 +20,7 @@
 #include "chatwindowconfig.h"
 #include "emoticonthemedelegate.h"
 #include "emoticonthemeitem.h"
+#include "kopetebehaviorsettings.h"
 
 #include <QCheckBox>
 #include <QDir>
@@ -220,6 +221,12 @@ ChatWindowConfig::ChatWindowConfig(QWidget *parent, const QVariantList &args )
 	m_tab->addTab(colorsWidget, i18n("Colors && Fonts"));
 	addConfig( Kopete::AppearanceSettings::self(), colorsWidget );
 
+//--------- tab tab --------------------------
+	QWidget *tabWidget = new QWidget(m_tab);
+	m_tabUi.setupUi(tabWidget);
+	m_tab->addTab(tabWidget, i18n("&Tabs"));
+	addConfig( Kopete::BehaviorSettings::self(), tabWidget );
+
 	load();
 }
 
@@ -471,6 +478,7 @@ void ChatWindowConfig::slotDeleteChatStyle()
 	{
 		KMessageBox::queuedMessageBox(this, KMessageBox::Sorry, i18nc("@info", "An error occurred while trying to delete the <resource>%1</resource> Chat Window Style. Your account might not have permission to remove it.", styleName));
 	}
+	slotUpdateChatPreview();
 }
 
 void ChatWindowConfig::slotGetChatStyles()
