@@ -81,6 +81,7 @@ public:
 	unsigned long int idleTime;
 
 	Kopete::StatusMessage statusMessage;
+	KToggleAction* toggleAlwaysVisibleAction;
 };
 
 Contact::Contact( Account *account, const QString &contactId,
@@ -91,6 +92,8 @@ Contact::Contact( Account *account, const QString &contactId,
 
 	d->contactId = contactId;
 	d->metaContact = parent;
+	connect( d->metaContact, SIGNAL(destroyed(QObject*)), this, SLOT(slotMetaContactDestroyed(QObject*)) );
+
 	d->fileCapable = false;
 	d->account = account;
 	d->idleTime = 0;
@@ -150,9 +153,9 @@ void Contact::setOnlineStatus( const OnlineStatus &status )
 	if( oldStatus.status() == OnlineStatus::Offline &&
 		status.status() != OnlineStatus::Offline )
 	{
-		setProperty( globalProps->onlineSince(), QDateTime::currentDateTime() );
-		/*kDebug(14010) << "REMOVING lastSeen property for " <<
-			d->displayName << endl;*/
+		if ( !hasProperty( globalProps->onlineSince().key() ) )
+			setProperty( globalProps->onlineSince(), QDateTime::currentDateTime() );
+		// kDebug(14010) << "REMOVING lastSeen property for " << nickName();
 		removeProperty( globalProps->lastSeen() );
 	}
 	else if( oldStatus.status() != OnlineStatus::Offline &&
@@ -160,8 +163,7 @@ void Contact::setOnlineStatus( const OnlineStatus &status )
 		status.status() == OnlineStatus::Offline ) // Contact went back offline
 	{
 		removeProperty( globalProps->onlineSince() );
-		/*kDebug(14010) << "SETTING lastSeen property for " <<
-			d->displayName << endl;*/
+		// kDebug(14010) << "SETTING lastSeen property for " << nickName();
 		setProperty( globalProps->lastSeen(), QDateTime::currentDateTime() );
 	}
 
@@ -279,6 +281,11 @@ KMenu* Contact::popupMenu( ChatSession *manager )
 	{
 		KAction* changeMetaContact = KopeteStdAction::changeMetaContact( this, SLOT( changeMetaContact() ), menu );
 		menu->addAction( changeMetaContact );
+
+		d->toggleAlwaysVisibleAction = new KToggleAction( i18n( "Visible when offline" ), menu );
+		d->toggleAlwaysVisibleAction->setChecked( property( Kopete::Global::Properties::self()->isAlwaysVisible() ).value().toBool() );
+		menu->addAction( d->toggleAlwaysVisibleAction );
+		connect( d->toggleAlwaysVisibleAction, SIGNAL( toggled(bool) ), this, SLOT( toggleAlwaysVisible() ) );
 	}
 
 	menu->addAction( KopeteStdAction::contactInfo( this, SLOT( slotUserInfo() ), menu ) );
@@ -296,6 +303,13 @@ KMenu* Contact::popupMenu( ChatSession *manager )
 	return menu;
 }
 
+void Contact::toggleAlwaysVisible()
+{
+	bool alwaysVisible = property( Kopete::Global::Properties::self()->isAlwaysVisible() ).value().toBool();
+	setProperty( Kopete::Global::Properties::self()->isAlwaysVisible(), !alwaysVisible );
+	d->toggleAlwaysVisibleAction->setChecked( !alwaysVisible );
+}
+
 void Contact::changeMetaContact()
 {
 	KDialog *moveDialog = new KDialog( Kopete::UI::Global::mainWidget() );
@@ -340,6 +354,14 @@ void Contact::changeMetaContact()
 	moveDialog->deleteLater();
 }
 
+void Contact::slotMetaContactDestroyed( QObject* mc )
+{
+	if (mc != d->metaContact)
+		return;
+
+	d->metaContact = 0;
+}
+
 void Contact::setMetaContact( MetaContact *m )
 {
 	MetaContact *old = d->metaContact;
@@ -349,6 +371,7 @@ void Contact::setMetaContact( MetaContact *m )
 	if( old )
 	{
 		old->removeContact( this );
+		disconnect( old, SIGNAL(destroyed(QObject*)), this, SLOT(slotMetaContactDestroyed(QObject*)) );
 
 		if(old->contacts().isEmpty())
 		{
@@ -364,11 +387,12 @@ void Contact::setMetaContact( MetaContact *m )
 	}
 
 	d->metaContact = m;
+	setParent( m );
 
 	if( m )
 	{
 		m->addContact( this );
-		setParent( m );
+		connect( m, SIGNAL(destroyed(QObject*)), this, SLOT(slotMetaContactDestroyed(QObject*)) );
 		// it is necessary to call this write here, because MetaContact::addContact() does not differentiate
 		// between adding completely new contacts (which should be written to kabc) and restoring upon restart
 		// (where no write is needed).
@@ -494,7 +518,6 @@ bool Contact::isOnline() const
 	return onlineStatus().isDefinitelyOnline();
 }
 
-
 bool Contact::isFileCapable() const
 {
 	return d->fileCapable;
