@@ -5,7 +5,7 @@
     Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
               (c) 2008      Novell, Inc.
 
-    Based on Iris, Copyright (C) 2003  Justin Karneges
+    Based on Iris, Copyright (C) 2003  Justin Karneges <justin@affinix.com>
 
     Kopete (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
  
@@ -19,8 +19,10 @@
     *************************************************************************
 */
 
-#include <qapplication.h>
-#include <qtimer.h>
+#include <QApplication>
+#include <QByteArray>
+#include <QList>
+#include <QTimer>
 
 #include "chatroommanager.h"
 #include "gwclientstream.h"
@@ -45,6 +47,8 @@
 #include "userdetailsmanager.h"
 #include "client.h"
 
+namespace GroupWise {
+
 class Client::ClientPrivate
 {
 public:
@@ -63,13 +67,14 @@ public:
 	UserDetailsManager * userDetailsMgr;
 	PrivacyManager * privacyMgr;
 	uint protocolVersion;
-	QValueList<GroupWise::CustomStatus> customStatuses;
+	QList<GroupWise::CustomStatus> customStatuses;
 	QTimer * keepAliveTimer;
 };
 
 Client::Client(QObject *par, uint protocolVersion )
-:QObject(par, "groupwiseclient")
+:QObject(par)
 {
+        setObjectName("groupwiseclient");
 	d = new ClientPrivate;
 /*	d->tzoffset = 0;*/
 	d->active = false;
@@ -80,8 +85,10 @@ Client::Client(QObject *par, uint protocolVersion )
 	d->root = new Task(this, true);
 	d->chatroomMgr = 0;
 	d->requestFactory = new RequestFactory;
-	d->userDetailsMgr = new UserDetailsManager( this, "userdetailsmgr" );
-	d->privacyMgr = new PrivacyManager( this, "privacymgr" );
+	d->userDetailsMgr = new UserDetailsManager( this );
+	d->userDetailsMgr->setObjectName( "userdetailsmgr" );
+	d->privacyMgr = new PrivacyManager( this );
+	d->privacyMgr->setObjectName( "privacymgr" );
 	d->stream = 0;
 	d->protocolVersion = protocolVersion;
 	// Sends regular keepalives so the server knows we are still running
@@ -93,7 +100,6 @@ Client::~Client()
 {
 	delete d->root;
 	delete d->requestFactory;
-	delete d->userDetailsMgr;
 	delete d;
 }
 
@@ -185,7 +191,7 @@ int Client::port()
 	return d->port;
 }
 
-QValueList<GroupWise::CustomStatus> Client::customStatuses()
+QList<GroupWise::CustomStatus> Client::customStatuses()
 {
 	return d->customStatuses;
 }
@@ -194,7 +200,7 @@ void Client::initialiseEventTasks()
 {
 	// The StatusTask handles incoming status changes
 	StatusTask * st = new StatusTask( d->root ); // FIXME - add an additional EventRoot?
-	connect( st, SIGNAL( gotStatus( const QString &, Q_UINT16, const QString & ) ), SIGNAL( statusReceived( const QString &, Q_UINT16, const QString & ) ) );
+	connect( st, SIGNAL( gotStatus( const QString &, quint16, const QString & ) ), SIGNAL( statusReceived( const QString &, quint16, const QString & ) ) );
 	// The ConferenceTask handles incoming conference events, messages, joins, leaves, etc
 	ConferenceTask * ct = new ConferenceTask( d->root ); 
 	connect( ct, SIGNAL( message( const ConferenceEvent & ) ), SLOT( ct_messageReceived( const ConferenceEvent & ) ) );
@@ -230,7 +236,7 @@ void Client::requestStatus( const QString & userDN )
 {
 	GetStatusTask * gst = new GetStatusTask( d->root );
 	gst->userDN( userDN );
-	connect( gst, SIGNAL( gotStatus( const QString &, Q_UINT16, const QString & ) ), SIGNAL( statusReceived( const QString &, Q_UINT16, const QString & ) ) );
+	connect( gst, SIGNAL( gotStatus( const QString &, quint16, const QString & ) ), SIGNAL( statusReceived( const QString &, quint16, const QString & ) ) );
 	gst->go( true );
 }
 
@@ -299,7 +305,7 @@ void Client::sendInvitation( const GroupWise::ConferenceGuid & guid, const QStri
 {
 	SendInviteTask * sit = new SendInviteTask( d->root );
 	QStringList invitees( dn );
-	sit->invite( guid, dn, message );
+	sit->invite( guid, invitees, message );
 	sit->go( true );
 }
 
@@ -326,7 +332,7 @@ void Client::lt_loginFinished()
 		debug( "Client::lt_loginFinished() LOGIN SUCCEEDED" );
 		// set our initial status
 		SetStatusTask * sst = new SetStatusTask( d->root );
-		sst->status( GroupWise::Available, QString::null, QString::null );
+		sst->status( GroupWise::Available, QString(), QString() );
 		sst->go( true );
 		emit loggedIn();
 		// fetch details for any privacy list items that aren't in our contact list.
@@ -359,7 +365,7 @@ void Client::ct_messageReceived( const ConferenceEvent & messageEvent )
 	RTF2HTML parser;
 	QString rtf = messageEvent.message;
 	if ( !rtf.isEmpty() )
-		transformedEvent.message = parser.Parse( rtf.latin1(), "" );
+		transformedEvent.message = parser.Parse( rtf.toLatin1(), "" );
 
 	// fixes for RTF to HTML conversion problems
 	// we can drop these once the server reenables the sending of unformatted text
@@ -434,7 +440,7 @@ QString Client::userAgent()
 	return QString::fromLatin1( "%1/%2 (%3)" ).arg( d->clientName, d->clientVersion, d->osname );
 }
 
-QCString Client::ipAddress()
+QByteArray Client::ipAddress()
 {
 	// TODO: remove hardcoding
 	return "10.10.11.103";
@@ -466,9 +472,9 @@ void Client::send( Request * request )
 void Client::debug( const QString &str )
 {
 #ifdef LIBGW_USE_KDEBUG
-	kdDebug( GROUPWISE_DEBUG_LIBGW ) << "debug: " << str << endl;
+	kDebug() << str;
 #else
-	qDebug( "CLIENT: %s\n", str.ascii() );
+	qDebug() << "CLIENT: " << str.toAscii();
 #endif
 }
 
@@ -508,7 +514,10 @@ uint Client::protocolVersion() const
 ChatroomManager * Client::chatroomManager()
 {
 	if ( !d->chatroomMgr )
-		d->chatroomMgr = new ChatroomManager( this, "chatroommgr" );
+	{
+		d->chatroomMgr = new ChatroomManager( this );
+		d->chatroomMgr->setObjectName( "chatroommgr" );
+	}
 	return d->chatroomMgr;
 }
 
@@ -538,4 +547,6 @@ void Client::smt_messageSent()
 	}
 }
 
+}
+
 #include "client.moc"
