@@ -154,7 +154,7 @@ void JabberChatSession::slotUpdateDisplayName ()
 	XMPP::Jid jid = static_cast<JabberBaseContact*>(chatMembers.first())->rosterItem().jid();
 
 	if ( !mResource.isEmpty () )
-		jid.withResource ( mResource );
+		jid = jid.withResource ( mResource );
 
 	QString statusText = i18nc("a contact's online status in parenthesis.", " (%1)",
 							  chatMembers.first()->onlineStatus().description() );
@@ -262,7 +262,7 @@ void JabberChatSession::sendNotification( Event event )
 		send_msg_event=false;
 		foreach(Kopete::Contact *c , members())
 		{
-			JabberContact *contact=static_cast<JabberContact*>(c);
+			JabberBaseContact *contact = static_cast<JabberBaseContact*>(c);
 			if(contact->isContactRequestingEvent( msg_event ))
 			{
 				send_msg_event=true;
@@ -287,12 +287,12 @@ void JabberChatSession::sendNotification( Event event )
 	if( !members().isEmpty() && (send_state || send_msg_event) )
 	{
 		// create JID for the recipient
-		JabberContact *recipient = static_cast<JabberContact*>(members().first());
+		JabberBaseContact *recipient = static_cast<JabberBaseContact*>(members().first());
 		XMPP::Jid toJid = recipient->rosterItem().jid();
 
 		// set resource properly if it has been selected already
 		if ( !resource().isEmpty () )
-			toJid.withResource ( resource () );
+			toJid = toJid.withResource ( resource () );
 
 		XMPP::Message message;
 
@@ -352,7 +352,7 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
 		XMPP::Jid toJid = recipient->rosterItem().jid();
 
 		if( !resource().isEmpty () )
-			toJid.withResource ( resource() );
+			toJid = toJid.withResource ( resource() );
 
 		jabberMessage.setTo ( toJid );
 
@@ -360,7 +360,7 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
 		jabberMessage.setSubject ( message.subject () );
 		jabberMessage.setTimeStamp ( message.timestamp () );
 
-		if ( message.plainBody().indexOf ( "-----BEGIN PGP MESSAGE-----" ) != -1 )
+		if ( ! account()->oldEncrypted() && message.plainBody().indexOf ( "-----BEGIN PGP MESSAGE-----" ) != -1 )
 		{
 			/*
 			 * This message is encrypted, so we need to set
@@ -371,9 +371,9 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
 			 */
 
 			// please don't translate the following string
-			jabberMessage.setBody ( i18n ( "This message is encrypted." ) );
+			jabberMessage.setBody ( "This message is signed or encrypted." );
 
-			QString encryptedBody = message.plainBody ();
+			QString encryptedBody = message.plainBody().trimmed();
 
 			// remove PGP header and footer from message
 			encryptedBody.truncate ( encryptedBody.length () - QString("-----END PGP MESSAGE-----").length () - 2 );
@@ -466,7 +466,7 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
 void JabberChatSession::slotSendFile()
 {
 	QList<Kopete::Contact*>contacts = members();
-	static_cast<JabberContact *>(contacts.first())->sendFile();
+	contacts.first()->sendFile();
 }
 
 
