@@ -6,8 +6,7 @@
 #include <qlabel.h>
 #include "addcontactpage.h"
 
-class aimAddContactUI;
-class AIMAccount;
+namespace Ui { class aimAddContactUI; }
 namespace Kopete
 {
 class Account; 
@@ -19,8 +18,7 @@ class AIMAddContactPage : public AddContactPage
 Q_OBJECT
 
 public:
-	AIMAddContactPage(bool connected, QWidget *parent=0,
-			    const char *name=0);
+	explicit AIMAddContactPage(bool connected, QWidget *parent=0);
 	~AIMAddContactPage();
 
 	/** Validates the data entered */
@@ -30,9 +28,7 @@ public:
 
 protected:
 	/** The actual GUI */
-	aimAddContactUI *m_gui;
-	QLabel *noaddMsg1;
-	QLabel *noaddMsg2;
+	Ui::aimAddContactUI *m_gui;
 	bool canadd;
 };
 #endif
