@@ -17,7 +17,8 @@
 */
 
 #include "connectionhandler.h"
-#include <qvaluelist.h>
+#include <qlist.h>
+#include <qmap.h>
 #include <kdebug.h>
 #include "connection.h"
 #include "oscartypes.h"
@@ -25,8 +26,8 @@
 class ConnectionHandler::Private
 {
 public:
-	QValueList<Connection*> connections;
-    QMap<Connection*, ConnectionRoomInfo> chatRoomConnections;
+	QList<Connection*> connections;
+	QMap<Connection*, ConnectionRoomInfo> chatRoomConnections;
 };
 
 ConnectionHandler::ConnectionHandler()
@@ -47,24 +48,24 @@ void ConnectionHandler::append( Connection* c )
 
 void ConnectionHandler::remove( Connection* c )
 {
-	kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "Removing connection "
+	kDebug(OSCAR_RAW_DEBUG) << "Removing connection "
 		<< c << endl;
-	d->connections.remove( c );
+	d->connections.removeAll( c );
 	c->deleteLater();
 }
 
 void ConnectionHandler::remove( int family )
 {
-	kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "Removing all connections " <<
+	kDebug(OSCAR_RAW_DEBUG) << "Removing all connections " <<
 		"supporting family " << family << endl;
-	QValueList<Connection*>::iterator it = d->connections.begin();
-	QValueList<Connection*>::iterator itEnd = d->connections.end();
+	QList<Connection*>::iterator it = d->connections.begin();
+	QList<Connection*>::iterator itEnd = d->connections.end();
 	for ( ; it != itEnd; ++it )
 	{
 		if ( ( *it )->isSupported( family ) )
 		{
 			Connection* c = ( *it );
-			it = d->connections.remove( it );
+			it = d->connections.erase( it );
 			c->deleteLater();
 		}
 	}
@@ -72,7 +73,7 @@ void ConnectionHandler::remove( int family )
 
 void ConnectionHandler::clear()
 {
-	kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "Clearing all connections"
+	kDebug(OSCAR_RAW_DEBUG) << "Clearing all connections"
 		 << endl;
 	while ( !d->connections.isEmpty() )
 	{
@@ -84,8 +85,8 @@ void ConnectionHandler::clear()
 
 Connection* ConnectionHandler::connectionForFamily( int family ) const
 {
-	QValueList<Connection*>::iterator it = d->connections.begin();
-	QValueList<Connection*>::iterator itEnd = d->connections.end();
+	QList<Connection*>::iterator it = d->connections.begin();
+	QList<Connection*>::iterator itEnd = d->connections.end();
 	int connectionCount = 0;
 	Connection* lastConnection = 0;
 	for ( ; it != itEnd; ++it )
@@ -110,9 +111,14 @@ Connection* ConnectionHandler::defaultConnection() const
 	return d->connections.first();
 }
 
+QList<Connection*> ConnectionHandler::connections() const
+{
+	return d->connections;
+}
+
 void ConnectionHandler::addChatInfoForConnection( Connection* c, Oscar::WORD exchange, const QString& room )
 {
-    if ( d->connections.findIndex( c ) == -1 )
+    if ( d->connections.indexOf( c ) == -1 )
         d->connections.append( c );
 
     ConnectionRoomInfo info = qMakePair( exchange, room );
@@ -125,7 +131,7 @@ Connection* ConnectionHandler::connectionForChatRoom( Oscar::WORD exchange, cons
     QMap<Connection*, ConnectionRoomInfo>::iterator it,  itEnd = d->chatRoomConnections.end();
     for ( it = d->chatRoomConnections.begin(); it != itEnd; ++it )
     {
-        if ( it.data() == infoToFind )
+        if ( it.value() == infoToFind )
         {
             Connection* c = it.key();
             return c;
@@ -137,26 +143,26 @@ Connection* ConnectionHandler::connectionForChatRoom( Oscar::WORD exchange, cons
 
 QString ConnectionHandler::chatRoomForConnection( Connection* c )
 {
-    if ( d->connections.findIndex( c ) == -1 )
-        return QString::null;
+    if ( d->connections.indexOf( c ) == -1 )
+        return QString();
 
     QMap<Connection*, ConnectionRoomInfo>::iterator it, itEnd = d->chatRoomConnections.end();
     for ( it = d->chatRoomConnections.begin(); it != itEnd; ++it )
     {
         if ( it.key() == c )
         {
-            QString room = it.data().second;
+            QString room = it.value().second;
             return room;
         }
     }
 
-    return QString::null;
+    return QString();
 }
 
 Oscar::WORD ConnectionHandler::exchangeForConnection( Connection* c )
 {
 
-    if ( d->connections.findIndex( c ) == -1 )
+    if ( d->connections.indexOf( c ) == -1 )
         return 0xFFFF;
 
     QMap<Connection*, ConnectionRoomInfo>::iterator it, itEnd = d->chatRoomConnections.end();
@@ -164,7 +170,7 @@ Oscar::WORD ConnectionHandler::exchangeForConnection( Connection* c )
     {
         if ( it.key() == c )
         {
-            Oscar::WORD exchange = it.data().first;
+            Oscar::WORD exchange = it.value().first;
             return exchange;
         }
     }
