@@ -29,6 +29,7 @@
 #include <qstring.h>
 #include <kopetemetacontact.h>
 #include <kopeteonlinestatus.h>
+#include <kopetestatusmanager.h>
 #include <kopetecontactlist.h>
 #include <kopetecontact.h>
 #include <kopetegroup.h>
@@ -42,6 +43,7 @@
 #include <kopeteaddedinfoevent.h>
 
 #include <QDateTime>
+#include <QPointer>
 
 class SkypeAccountPrivate {
 	public:
@@ -78,9 +80,9 @@ class SkypeAccountPrivate {
 		///Do we wait before connecting?
 		int waitBeforeConnect;
 		///List of chat all chat sessions
-		QHash<QString, SkypeChatSession*> sessions;
+		QHash<QString, QPointer<SkypeChatSession> > sessions;
 		///Last used chat session
-		SkypeChatSession *lastSession;
+		QPointer <SkypeChatSession> lastSession;
 		///List of the conference calls
 		QHash<QString, SkypeConference*> conferences;
 		///List of existing calls
@@ -153,7 +155,7 @@ SkypeAccount::SkypeAccount(SkypeProtocol *protocol, const QString& accountID) :
 	QObject::connect(&d->skype, SIGNAL(newCall(const QString&, const QString&)), this, SLOT(newCall(const QString&, const QString&)));
 	QObject::connect(&d->skype, SIGNAL(setMyselfName(const QString&)), this, SLOT(setMyselfName(const QString& )));
 	QObject::connect(&d->skype, SIGNAL(receivedMultiIM(const QString&, const QString&, const QString&, const QString&, const QDateTime&)), this, SLOT(receiveMultiIm(const QString&, const QString&, const QString&, const QString&, const QDateTime&)));
-	QObject::connect(&d->skype, SIGNAL(outgoingMessage(const QString&, const QString&)), this, SLOT(sentMessage(const QString&, const QString& )));
+	QObject::connect(&d->skype, SIGNAL(outgoingMessage(const QString&, const QString&, const QString& )), this, SLOT(sentMessage(const QString&, const QString&, const QString& )));
 	QObject::connect(&d->skype, SIGNAL(groupCall(const QString&, const QString& )), this, SLOT(groupCall(const QString&, const QString& )));
 	QObject::connect(&d->skype, SIGNAL(receivedAuth(const QString &, const QString &)), this, SLOT(receivedAuth(const QString &, const QString &)));
 	QObject::connect(Kopete::ContactList::self(), SIGNAL(groupRemoved (Kopete::Group *)), this, SLOT(deleteGroup (Kopete::Group *) ) );
@@ -205,7 +207,7 @@ void SkypeAccount::setAway(bool away, const QString &reason) {
 }
 
 void SkypeAccount::setOnlineStatus(const Kopete::OnlineStatus &status, const Kopete::StatusMessage &reason, const OnlineStatusOptions& options) {
-	kDebug(SKYPE_DEBUG_GLOBAL);
+	kDebug(SKYPE_DEBUG_GLOBAL) << "status message:" << reason.message();
 	Q_UNUSED(options);
 	if (status == d->protocol->Online){
 		d->skype.setOnline();//Go online
@@ -242,12 +244,13 @@ void SkypeAccount::setOnlineStatus(const Kopete::OnlineStatus &status, const Kop
 void SkypeAccount::setStatusMessage(const Kopete::StatusMessage &statusMessage)
 {
 	d->skype.setUserProfileRichMoodText(statusMessage.message());
+	myself()->setStatusMessage(statusMessage.message());
 }
 
 void SkypeAccount::disconnect() {
 	kDebug(SKYPE_DEBUG_GLOBAL);
 
-	setOnlineStatus(d->protocol->Offline, Kopete::StatusMessage());
+	setOnlineStatus(d->protocol->Offline, Kopete::StatusManager::self()->globalStatusMessage());
 }
 
 SkypeContact *SkypeAccount::contact(const QString &id) {
@@ -262,9 +265,9 @@ void SkypeAccount::connect(const Kopete::OnlineStatus &Status) {
 	if ((Status != d->protocol->Online) && (Status != d->protocol->Away) &&
 		(Status != d->protocol->NotAvailable) && (Status != d->protocol->DoNotDisturb) &&
 		(Status != d->protocol->SkypeMe))//some strange online status, taje a default one
-			setOnlineStatus(d->protocol->Online, Kopete::StatusMessage());
+			setOnlineStatus(d->protocol->Online, Kopete::StatusManager::self()->globalStatusMessage());
 	else
-		setOnlineStatus(Status, Kopete::StatusMessage());//just change the status
+		setOnlineStatus(Status, Kopete::StatusManager::self()->globalStatusMessage());//just change the status
 
 }
 
@@ -399,7 +402,7 @@ void SkypeAccount::newUser(const QString &name, int groupID) {
 		return;
 	}
 
-	addContact(name, d->skype.getDisplayName(name), skypeGroup, ChangeKABC);
+	addContact(name, d->skype.getContactDisplayName(name), skypeGroup, ChangeKABC);
 }
 
 void SkypeAccount::prepareContact(SkypeContact *contact) {
@@ -438,16 +441,25 @@ SkypeProtocol * SkypeAccount::protocol() {
 void SkypeAccount::sendMessage(Kopete::Message &message, const QString &chat) {
 	kDebug(SKYPE_DEBUG_GLOBAL);
 
+	QString id;
 	if (chat.isEmpty()) {
 		const QString &user = message.to().at(0)->contactId();//get id of the first contact, messages to multiple people are not yet possible
 		const QString &body = message.plainBody().trimmed();//get the text of the message
 
-		d->skype.send(user, body);//send it by skype
+		id = d->skype.send(user, body);//send it by skype
 	} else {
 		const QString &body = message.plainBody().trimmed();
-
-		d->skype.sendToChat(chat, body);
+		id = d->skype.sendToChat(chat, body);
 	}
+
+	// Append message to chat session
+	QString chatId = d->skype.getMessageChat(id);
+
+	// Use last session if available (could be set by skypechatsession)
+	SkypeChatSession *session = d->lastSession?d->lastSession:d->sessions.value(chatId);
+
+	if(session)
+		session->sentMessage(message, id);
 }
 
 bool SkypeAccount::getHitchHike() const {
@@ -572,7 +584,7 @@ QString SkypeAccount::getUserLabel(const QString &userId) {
 	Kopete::Contact *cont = contact(userId);
 
 	if (!cont) {
-		addContact(userId, d->skype.getDisplayName(userId), 0L, Temporary);//create a temporary contact
+		addContact(userId, d->skype.getContactDisplayName(userId), 0L, Temporary);//create a temporary contact
 
 		cont = (contacts().value(userId));//It should be there now
 		if (!cont)
@@ -635,7 +647,7 @@ int SkypeAccount::getWaitBeforeConnect() const {
 SkypeContact *SkypeAccount::getContact(const QString &userId) {
 	SkypeContact *cont = static_cast<SkypeContact *> (contacts().value(userId));//get the contact
 	if (!cont) {//We do not know such contact
-		addContact(userId, d->skype.getDisplayName(userId), 0L, Temporary);//create a temporary contact
+		addContact(userId, d->skype.getContactDisplayName(userId), 0L, Temporary);//create a temporary contact
 
 		cont = static_cast<SkypeContact *> (contacts().value(userId));//It should be there now
 	}
@@ -701,10 +713,14 @@ void SkypeAccount::gotMessageId(const QString &messageId) {
 	d->lastSession = 0L;
 }
 
-void SkypeAccount::sentMessage(const QString &body, const QString &chat) {
+void SkypeAccount::sentMessage(const QString &id, const QString &body, const QString &chat) {
 	kDebug(SKYPE_DEBUG_GLOBAL) << "chat: " << chat;
 
 	SkypeChatSession *session = d->sessions.value(chat);
+
+	if ( ! session || session->ackMessage(id, false) )
+		return;
+
 	const QStringList &users = d->skype.getChatUsers(chat);
 	QList<Kopete::Contact*> *recv = 0L;
 
@@ -1013,9 +1029,9 @@ void SkypeAccount::openFileTransfer(const QString &user, const QString &url) {
 	d->skype.openFileTransfer(user, url);
 }
 
-void SkypeAccount::setDisplayName(const QString &user, const QString &name) {
+void SkypeAccount::setContactDisplayName(const QString &user, const QString &name) {
 	kDebug(SKYPE_DEBUG_GLOBAL) << user << name;
-	d->skype.setDisplayName(user, name);
+	d->skype.setContactDisplayName(user, name);
 }
 
 void SkypeAccount::receivedAuth(const QString &user, const QString &info) {
@@ -1073,7 +1089,7 @@ void SkypeAccount::stopSendingVideo(const QString &callId) {
 void SkypeAccount::userInfo(const QString &user) {
 	kDebug(SKYPE_DEBUG_GLOBAL) << user;
 	if ( ! contact(user) ) {
-		addContact(user, d->skype.getDisplayName(user), 0L, Temporary);//create a temporary contact
+		addContact(user, d->skype.getContactDisplayName(user), 0L, Temporary);//create a temporary contact
 		if ( ! contact(user) ) {
 			KMessageBox::error(0L, i18n("Cannot open info about user %1", user), i18n("Skype protocol"));
 			return;//contact arent in contact list - skip it
@@ -1094,17 +1110,20 @@ void SkypeAccount::SkypeActionHandler(const QString &message) {
 	}
 
 	QString command;
+	QString subcommands;
 	QString user;
 
 	if ( message.startsWith("callto:", Qt::CaseInsensitive) ) {
 		command = "call";
-		user = message.section(":", -1).section("/", -1).trimmed();
+		user = message.section(':', -1).section('/', -1).trimmed();
 	} else if ( message.startsWith("tel:", Qt::CaseInsensitive) ) {
 		command = "chat";
-		user = message.section(":", -1).section("/", -1).trimmed();
+		user = message.section(':', -1).section('/', -1).trimmed();
 	} else if ( message.startsWith("skype:", Qt::CaseInsensitive) ) {
-		command = message.section("?", -1).trimmed();
-		user = message.section(":", -1).section("?", 0, 0).trimmed();
+		command = message.section('?', -1).section('&', 0, 0).trimmed();
+		//TODO: Add support for subcommands
+//		subcommands = QUrl::fromPercentEncoding(message.section('&', 1, -1).toUtf8());
+		user = message.section(':', -1).section('?', 0, 0).trimmed();
 		if ( command.isEmpty() ) //set default double click action = open chat window
 			command = "chat";
 	} else {
@@ -1127,6 +1146,7 @@ void SkypeAccount::SkypeActionHandler(const QString &message) {
 		makeCall(user);//Start call with user
 	} else if ( command == "chat" ) {
 		//TODO: Add support for multichat
+		//TODO: Add support for topic of chat
 		chatUser(user);//Open chat window
 	} else if ( command == "sendfile" ) {
 		openFileTransfer(user);//Open file transfer dialog
@@ -1136,7 +1156,7 @@ void SkypeAccount::SkypeActionHandler(const QString &message) {
 	} else if ( command == "userinfo" ) {//TODO: Open option dialog (with all thisa options instead userinfo) and support unknown contacts who arent in contact list
 		userInfo(user);
 	} else {
-		kDebug(SKYPE_DEBUG_GLOBAL) << "Unknown command";
+		kDebug(SKYPE_DEBUG_GLOBAL) << "Unknown action command from SkypeActionHandler:" << command;
 		KMessageBox::error(0L, i18n("Unknown action from SkypeActionHandler"), i18n("Skype protocol"));
 		return;//Unknow command
 	}
