@@ -13,30 +13,37 @@
     *                                                                       *
     *************************************************************************
 */
+
+#include "testbedprotocol.h"
+
+#include <QList>
 #include <kgenericfactory.h>
 #include <kdebug.h>
 
 #include "kopeteaccountmanager.h"
-
 #include "testbedaccount.h"
 #include "testbedcontact.h"
-#include "testbedprotocol.h"
 #include "testbedaddcontactpage.h"
 #include "testbededitaccountwidget.h"
 
-typedef KGenericFactory<TestbedProtocol> TestbedProtocolFactory;
-K_EXPORT_COMPONENT_FACTORY( kopete_testbed, TestbedProtocolFactory( "kopete_testbed" )  )
+K_PLUGIN_FACTORY( TestbedProtocolFactory, registerPlugin<TestbedProtocol>(); )
+K_EXPORT_PLUGIN( TestbedProtocolFactory( "kopete_testbed" ) )
 
 TestbedProtocol *TestbedProtocol::s_protocol = 0L;
 
-TestbedProtocol::TestbedProtocol( QObject* parent, const char *name, const QStringList &/*args*/ )
-	: Kopete::Protocol( TestbedProtocolFactory::instance(), parent, name ),
-	  testbedOnline(  Kopete::OnlineStatus::Online, 25, this, 0,  QString::null,  i18n( "Online" ),   i18n( "O&nline" ) ),
-	  testbedAway(  Kopete::OnlineStatus::Away, 25, this, 1, "msn_away",  i18n( "Away" ),   i18n( "&Away" ) ),
-	  testbedOffline(  Kopete::OnlineStatus::Offline, 25, this, 2,  QString::null,  i18n( "Offline" ),   i18n( "O&ffline" ) )
+TestbedProtocol::TestbedProtocol( QObject* parent, const QVariantList &/*args*/ )
+	: Kopete::Protocol( TestbedProtocolFactory::componentData(), parent ),
+	  testbedOnline(  Kopete::OnlineStatus::Online, 25, this, 0,  QStringList(QString()),
+			  i18n( "Online" ),   i18n( "O&nline" ), Kopete::OnlineStatusManager::Online ),
+	  testbedAway(  Kopete::OnlineStatus::Away, 25, this, 1, QStringList(QLatin1String("msn_away")),
+			  i18n( "Away" ),   i18n( "&Away" ), Kopete::OnlineStatusManager::Away ),
+	  testbedBusy(  Kopete::OnlineStatus::Busy, 25, this, 1, QStringList(QLatin1String("msn_busy")),
+			  i18n( "Busy" ),   i18n( "&Busy" ), Kopete::OnlineStatusManager::Busy ),
+	  testbedOffline(  Kopete::OnlineStatus::Offline, 25, this, 2,  QStringList(QString()),
+			  i18n( "Offline" ),   i18n( "O&ffline" ), Kopete::OnlineStatusManager::Offline )
 
 {
-	kdDebug( 14210 ) << k_funcinfo << endl;
+	kDebug( 14210 ) ;
 
 	s_protocol = this;
 }
@@ -54,35 +61,44 @@ Kopete::Contact *TestbedProtocol::deserializeContact(
 	QString displayName = serializedData[ "displayName" ];
 	QString type = serializedData[ "contactType" ];
 
-	TestbedContact::TestbedContactType tbcType;
-	if ( type == QString::fromLatin1( "echo" ) )
+	TestbedContact::Type tbcType;
+	if ( type == QLatin1String( "group" ) )
+		tbcType = TestbedContact::Group;
+	else if ( type == QLatin1String( "echo" ) )
 		tbcType = TestbedContact::Echo;
-	if ( type == QString::fromLatin1( "null" ) )
+	else if ( type == QLatin1String( "null" ) )
 		tbcType = TestbedContact::Null;
 	else
 		tbcType = TestbedContact::Null;
 
-	QDict<Kopete::Account> accounts = Kopete::AccountManager::self()->accounts( this );
+	QList<Kopete::Account*> accounts = Kopete::AccountManager::self()->accounts( this );
+	Kopete::Account* account = 0;
+	foreach( Kopete::Account* acct, accounts )
+	{
+		if ( acct->accountId() == accountId )
+			account = acct;
+	}
 
-	Kopete::Account *account = accounts[ accountId ];
 	if ( !account )
 	{
-		kdDebug(14210) << "Account doesn't exist, skipping" << endl;
+		kDebug(14210) << "Account doesn't exist, skipping";
 		return 0;
 	}
 
-	return new TestbedContact(account, contactId, tbcType, displayName, metaContact);
+	TestbedContact * contact = new TestbedContact(account, contactId, displayName, metaContact);
+	contact->setType( tbcType );
+	return contact;
 }
 
 AddContactPage * TestbedProtocol::createAddContactWidget( QWidget *parent, Kopete::Account * /* account */ )
 {
-	kdDebug( 14210 ) << "Creating Add Contact Page" << endl;
+	kDebug( 14210 ) << "Creating Add Contact Page";
 	return new TestbedAddContactPage( parent );
 }
 
 KopeteEditAccountWidget * TestbedProtocol::createEditAccountWidget( Kopete::Account *account, QWidget *parent )
 {
-	kdDebug(14210) << "Creating Edit Account Page" << endl;
+	kDebug(14210) << "Creating Edit Account Page";
 	return new TestbedEditAccountWidget( parent, account );
 }
 
