@@ -1156,8 +1156,9 @@ WlmAccount::slotInitialEmailNotification (const int unread_inbox)
 
     notification->setText(i18np( "You have one unread message in your Hotmail inbox.",
                                  "You have %1 unread messages in your Hotmail inbox.", unread_inbox));
-    notification->setActions(( QStringList() << i18nc("@action", "Open Inbox" ) << i18nc("@action", "Ignore" )) );
+    notification->setActions(( QStringList() << i18nc("@action", "Open Inbox" ) << i18nc("@action", "Close" )) );
     notification->setFlags(KNotification::Persistent);
+    notification->setPixmap(accountIcon(KIconLoader::SizeMedium));
     QObject::connect(notification,SIGNAL(activated()), this , SLOT(slotOpenInbox()) );
     QObject::connect(notification,SIGNAL(action1Activated()), this, SLOT(slotOpenInbox()) );
     QObject::connect(notification,SIGNAL(action2Activated()), notification, SLOT(close()) );
@@ -1171,8 +1172,9 @@ WlmAccount::slotNewEmailNotification (const QString from, const QString subject)
     KNotification *notification= new KNotification ("msn_mail", Kopete::UI::Global::mainWidget());
 
     notification->setText(i18n( "New message from %1 in your Hotmail inbox.<p>Subject: %2", from, subject));
-    notification->setActions(( QStringList() << i18nc("@action", "Open Inbox" ) << i18nc("@action", "Ignore" )) );
+    notification->setActions(( QStringList() << i18nc("@action", "Open Inbox" ) << i18nc("@action", "Close" )) );
     notification->setFlags(KNotification::Persistent);
+    notification->setPixmap(accountIcon(KIconLoader::SizeMedium));
     QObject::connect(notification,SIGNAL(activated()), this , SLOT(slotOpenInbox()) );
     QObject::connect(notification,SIGNAL(action1Activated()), this, SLOT(slotOpenInbox()) );
     QObject::connect(notification,SIGNAL(action2Activated()), notification, SLOT(close()) );
@@ -1387,16 +1389,10 @@ void WlmAccount::logOff( Kopete::Account::DisconnectReason reason )
         c->setOnlineStatus (WlmProtocol::protocol ()->wlmOffline);
     }
 
-    if (m_transferManager)
-    {
-        delete m_transferManager;
-        m_transferManager = NULL;
-    }
-    if (m_chatManager)
-    {
-        delete m_chatManager;
-        m_chatManager = NULL;
-    }
+    delete m_transferManager;
+    m_transferManager = NULL;
+    delete m_chatManager;
+    m_chatManager = NULL;
     if (m_server)
     {
         QObject::disconnect (&m_server->cb, 0, 0, 0);
